美国往事 (豆瓣)
Description: 美国往事电影简介和剧情介绍,美国往事影评、图片、预告片、影讯、论坛、在线购票
Keywords: 美国往事,Once Upon a Time in America,美国往事影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.83豆瓣电影Top250

# 美国往事 Once Upon a Time in America (1984)

导演: 赛尔乔·莱昂内
编剧: 皮耶罗·德·贝纳迪 / 莱奥纳多·本韦努蒂 / 弗兰科·奥卡利 / 恩里科·梅迪欧力 / 弗兰科·费里尼 / 赛尔乔·莱昂内
主演: 罗伯特·德尼罗 / 詹姆斯·伍兹 / 伊丽莎白·麦戈文 / 乔·佩西 / 波特·杨 / 塔斯黛·韦尔德 / 特里特·威廉斯 / 丹尼·爱罗 / 理查德·布赖特 / 詹姆斯·海登 / 威廉·弗西斯 / 达兰妮·弗鲁格 / 拉里·拉普 / 理查德·弗让吉 / 罗伯特·哈珀 / 詹妮弗·康纳利
类型: 剧情 / 犯罪
制片国家/地区: 美国 / 意大利
语言: 英语 / 法语 / 意大利语
上映日期: 1984-02-17(波士顿首映) / 1984-09-28(意大利)
片长: 229分钟(导演剪辑版) / 251分钟(导演剪辑加长版)
又名: 四海兄弟(台) / 义薄云天(港) / C'era una volta in America
IMDb: tt0087843
豆瓣评分
引用
9.2
392585人评价
5星
66.0%
4星
27.4%
3星
5.8%
2星
0.5%
1星
0.2%
好于 98% 剧情片
好于 99% 犯罪片
想看 看过
评价:
推荐

## 美国往事的剧情简介 · · · · · ·

1933年，纽约流氓Noodles（罗伯特·德·尼罗 饰）因向哈洛伦警司（布鲁斯·巴伦堡 饰）通风报信害死了三名同伙而被追杀。逃亡之前，他打开了存放帮派基金的手提箱，里面却只有报纸。 1968年，已改名换姓的Noodles收到一封犹太会堂通知迁葬亲友的信。Noodles联系拉比，得知信是八个月前寄出的，他的三名同伙已被迁葬至一所豪华公墓。Noodles回到纽约，找老友莫（拉里·拉普 饰）了解情况，却一无所获。闲谈中，Noodles问起莫的妹妹黛博拉（伊丽莎白·麦戈文 饰）的情况，得知其已成名角。 原来，两人少时互有好感，但黛博拉（詹妮弗·康纳利 饰）志向高远脚踏实地，理智地将街头混混Noodles（斯科特·提勒 饰）拒于门外。 Noodles在公墓发现了一把钥匙，并用钥匙打开了当年存放手提箱的储物柜。这一次，箱子里有满满的百元钞，还有写着“下一份工作... (展开全部) 1933年，纽约流氓Noodles（罗伯特·德·尼罗 饰）因向哈洛伦警司（布鲁斯·巴伦堡 饰）通风报信害死了三名同伙而被追杀。逃亡之前，他打开了存放帮派基金的手提箱，里面却只有报纸。 1968年，已改名换姓的Noodles收到一封犹太会堂通知迁葬亲友的信。Noodles联系拉比，得知信是八个月前寄出的，他的三名同伙已被迁葬至一所豪华公墓。Noodles回到纽约，找老友莫（拉里·拉普 饰）了解情况，却一无所获。闲谈中，Noodles问起莫的妹妹黛博拉（伊丽莎白·麦戈文 饰）的情况，得知其已成名角。 原来，两人少时互有好感，但黛博拉（詹妮弗·康纳利 饰）志向高远脚踏实地，理智地将街头混混Noodles（斯科特·提勒 饰）拒于门外。 Noodles在公墓发现了一把钥匙，并用钥匙打开了当年存放手提箱的储物柜。这一次，箱子里有满满的百元钞，还有写着“下一份工作的预付款”的纸条…… ©豆瓣

## 美国往事的演职员 · · · · · · ( 全部 49 )

- 赛尔乔·莱昂内 导演
- 罗伯特·德尼罗 饰 Noodles
- 詹姆斯·伍兹 饰 Max
- 伊丽莎白·麦戈文 饰 Deborah
- 乔·佩西 饰 Frankie
- 波特·杨 饰 Joe

## 美国往事的视频和图片 · · · · · · ( 预告片1 | 视频评论2 · 添加 | 图片1854 · 添加 )

## 喜欢这部电影的人也喜欢 · · · · · ·

  教父2

  好家伙

  低俗小说

  上帝之城

  爱尔兰人

  枪火

  黑社会

  英雄本色

  无间道

  赌城风云

我要写短评

## 美国往事的短评 · · · · · · ( 全部 87355 条 )

热门 / 最新 / 好友

### 6378 有用 小易甫 看过 2009-02-21 13:03:14

一年多以后，我将它从四星改为了五星，期间未曾多看一遍。

### 2936 有用 维城乱马 看过 2013-07-13 22:12:39

有一种片子，伴随你走过热血沸腾的青春期，在成年后来看却又是另一番感受。在巴西，它叫《上帝之城》，在日本，它叫《大佬》，在韩国，它叫《朋友》，在香港，它叫《古惑仔》，在台湾，它叫《牯岭街少年杀人事件》，在大陆，它叫《阳光灿烂的日子》，最早的在美国，叫《 Once Upon a Time in America》。

### 3843 有用 王大根 看过 2016-12-20 23:11:50

两场强暴戏毕竟是吃不消，男性的传奇之路上似乎最少不得的就是美丽而无人格的女性牺牲品

### 1215 有用 Rema 看过 2017-04-15 11:52:26

个人史诗式的黑帮电影，也正如所有黑帮电影一样，拥有着史诗级别的直男癌

### 3637 有用 林愈静 看过 2006-04-21 20:27:06

姜文的阳光灿烂的日子，杨德昌的牯岭街少年杀人事件，韩国的朋友都是模仿这部

> 更多短评 87355条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 美国往事的影评 · · · · · · ( 全部 1574 条 )

热门 / 最新 / 好友
太空竹子 2006-09-24 12:32:17

## 《美国往事》的两个隐含情节

在家的时候，把〈美国往事〉的碟又找出来细细看了一遍，发现了以前没有注意的两个情节，算是导演埋下的伏笔吧，将其记录在此，希望有同样喜欢这部电影的人能够看到。 1、关键词：水牛城 buffalo city 影片前半部分，noodles在三个同伴死去遭人追杀时，到了火车站买了随机的最早... (展开)
7019 461 968回应 收起
修复的薄码.AVI 2008-05-26 09:11:07

## 很正经系列

这篇影评可能有剧透

【我来小分析一下《美国往事》里的性行为】 看来，我得把“补充一条”挪到最前边了：我也可以很煽情地表扬男人们的热血、友谊、仗义、等等。但别人早就这样做过很多次了。我想，我还不如找个新角度补缺捡漏呢。如果你想看煽情范儿的，搜一下其他评论吧，别跟这儿批判我狭隘、... (展开)
3428 892 477回应 收起
aratana 2007-02-26 11:28:24

## 《美国往事》：是男人就不能不看的电影

《美国往事》：是男人就不能不看的电影 上面的标题是泼皮的说法但接近真意，下面的标题是修饰的说法但接近装淡。 《美国往事》：关于意味深长的人生 引子 世事皆无完美，电影亦然。如果只选一部趋近于完美的电影，以我粗陋的观影量和品味来说，我选《美国往事》。虽然它没... (展开)
2228 310 182回应 收起
如如 2007-11-29 12:48:51

## 四小时的一生

这篇影评可能有剧透

四小时的一生 《美国往事》片长近乎4个小时，当电影落幕的时候，却丝毫不觉得它冗长，而是惊叹刚才窗外还是阳光灿烂，再抬头已是夕阳西下。人呆坐在沙发上好一会儿，缓不过来。 该电影被众多影评分类为黑帮电影，其实不然，纵使电影的确讲述了一群混混的生活，的确有血腥、撕... (展开)
1071 73 72回应 收起
微尘 2010-12-24 16:16:40

## 这个评论对于这部电影很有用

戴锦华借助麦茨的组合段理论所做的分析，现引用如下： 或许借助克·麦茨的大组合段理论[简称SP，见麦茨《电影语言》]，我们可以更为清晰地考察一下《美国往事》这部长达3小时40分钟影片(欧洲版)的颇为繁复的叙事及意义结构。 　　 1．序幕 非时序组合段 1993年... (展开)
778 29 59回应 收起
Darth_Vader 2016-02-07 20:16:40

## 251分钟的意大利加长版和229分钟的导演剪辑版对比

251分钟的意大利加长版和229分钟的导演剪辑版对比之后，增加了以下几个片段： ①(94:50-98:20)老年面条探望死去好友的陵墓，发现里面的钥匙和牌匾之后和陵墓主管的对话戏，在这里发现目的不明的汽车，老年面条走上前去汽车立即开走了，于是记下车牌号(和之后目睹汽车爆炸和关注... (展开)
659 10 76回应 收起
lalalalala 2012-11-12 22:24:45

## 两个女人

这篇影评可能有剧透

我知道这是一部男人不得不看的电影，里面的热血，情谊，背叛，理想，现实似乎很远，却也很近。 我花了七个小时看了两遍，却觉得什么都说不出来，很糟糕。 作为女性观众，撇开所有的故事不谈，我只想说一下这部电影中最重要的两个女人，Max和Noodles的女人carol 和deborah。 在... (展开)
589 32 63回应 收起
你读书少♂ 2018-12-29 11:16:42 #《美国往事》有哪些精彩的细节？

## 《美国往事》爱情篇：任时光荏苒，我对你的凝望一往情深

这篇影评可能有剧透

《美国往事》动人的细节千千万，以爱情为例。爱情这条线里面不但有无数痴情感动的细节，还有无数让人脊背发凉，细思极恐暗线。甚至读懂了这些细节，你就理解了这部电影为什么会是这样一个结局。以251分钟加长版为例，加长版多出来20分钟的细节，也多出来更多痛彻心扉的遗憾。 A... (展开)
576 13 100回应 收起
普璞 2010-03-18 14:49:37

## 爱的旁边是不理解，不理解的背后是证明——致很多人都没看懂的《美国往事》

这篇影评可能有剧透

看了一遍《美国往事》，又看了很多评论，发现很多人对部分关键情节都没有理解，我说两个最重要的地方： 一，最后max真的钻进垃圾搅拌机里死了吗？ 答案是NO，是完全肯定的NO，因为那辆搅拌车根本就不存在。 那辆搅拌车只是面条幻想出来的，根本就不存在。 这有一个证据，就是前... (展开)
496 104 129回应 收起
amoonsea 2011-01-31 20:04:13

## 影史上那著名的电话铃声——对《美国往事》开头的分析

看过《美国往事》的人想必会对影片开头那段刺耳的电话铃声印象深刻，可能许多人再看这段的时候会以为影片卡了。 这段电话铃声长达4分钟之久，其中伴随了多个场面的调度。这段铃声导演精心安排，使用了多种电影语言，这些巧妙地设计造就了影史上这经典的电话铃声！ ... (展开)
326 8 20回应 收起

> 更多影评 1574篇

添加新讨论

## 讨论区 · · · · · ·

你们说像不像四海兄弟 | 来自I'm |  | 2022-11-21 19:06:53
请教哪里看完整的啊 | 来自LO宣鑫 | 27 回应 | 2022-11-21 11:15:16
没莫里康内就废了 | 来自The Lost Man |  | 2022-11-21 09:57:25
请问腾讯视频的243分钟版本，对比完整版删减了哪些... | 来自大鱼约拿 | 16 回应 | 2022-11-20 21:38:51
话说这部片子有什么专门的影集之类的吗 | 来自lukeskywalker |  | 2022-11-20 01:19:11

> 去这部影片的讨论区（全部471条）

## 关于《美国往事》的问题 · · · · · · ( 全部72个 )

- 小男孩死前说的:"Noodles,I slipped.",怎么理解？ 14人回答
- 面条的最后一笑？ 36人回答

> 全部72个问题

## 在哪儿看这部电影 · · · · · ·

- 腾讯视频 VIP免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 【豆瓣五星电影集中营】(1/3) (影志)
- 电影学院本科生必看100部 (志国)
- 《电影手册》世上最美的100部电影 (大旗虎皮)
- 电影上的“三部曲”系列~~ (Black Tulip)

## 谁在看这部电影 · · · · · ·

- 凡尘
  6分钟前 看过
- 纱织NaNa
  8分钟前 想看
- 幻云
  8分钟前 看过

581879人看过 / 474473人想看

订阅美国往事的评论:
feed: rss 2.0